
# A Terminal User Interface for the PLATO Fast Camera

This is a new project to  provide a TUI to monitor and command the F-FEE for the Fast PLATO camera.

## Installation

This project requires the proper installation of the CGSE, which is the Common-EGSE that is developed to align and test the PLATO cameras. You can find information about the CGSE at https://ivs-kuleuven.github.io/plato-cgse-doc/.

Install the project in the virtual environment that you have set up for the CGSE:

```bash
$ python -m pip install f-fee-tui
```
